// Taken directly from jQuery 1.1.4
function Ajax(s) {
    var lastModified = {}; // Last-Modified header cache for next request

	var ajaxSettings = {
		global: true,
		type: "GET",
		timeout: 0,
		contentType: "application/x-www-form-urlencoded",
		processData: true,
		async: true,
		data: null
	},

	function extend() {
		// copy reference to target object
		var target = arguments[0] || {}, a = 1, al = arguments.length, deep = false;

		// Handle a deep copy situation
		if ( target.constructor == Boolean ) {
			deep = target;
			target = arguments[1] || {};
		}

		// extend jQuery itself if only one argument is passed
		if ( al == 1 ) {
			target = this;
			a = 0;
		}

		var prop;

		for ( ; a < al; a++ )
			// Only deal with non-null/undefined values
			if ( (prop = arguments[a]) != null )
				// Extend the base object
				for ( var i in prop ) {
					// Prevent never-ending loop
					if ( target == prop[i] )
						continue;

					// Recurse if we're merging object values
					if ( deep && typeof prop[i] == 'object' && target[i] )
						jQuery.extend( target[i], prop[i] );

					// Don't bring in undefined values
					else if ( prop[i] != undefined )
						target[i] = prop[i];
				}

		// Return the modified object
		return target;
	};

    function httpNotModified( xml, url ) {
    	try {
    		var xmlRes = xml.getResponseHeader("Last-Modified");

    		// Firefox always returns 200. check Last-Modified date
    		return xml.status == 304 || xmlRes == lastModified[url] || xml.status == undefined;
    	} catch(e){}
    	return false;
    }


    function httpSuccess( r ) {
    	try {
    		return !r.status && location.protocol == "file:" ||
    			( r.status >= 200 && r.status < 300 ) || r.status == 304 || r.status == undefined;
    	} catch(e){}
    	return false;
    }

    /* Get the data out of an XMLHttpRequest.
     * Return parsed XML if content-type header is "xml" and type is "xml" or omitted,
     * otherwise return plain text.
     * (String) data - The type of data that you're expecting back,
     * (e.g. "xml", "html", "script")
     */
    function httpData( r, type ) {
    	var ct = r.getResponseHeader("content-type");
    	var xml = type == "xml" || !type && ct && ct.indexOf("xml") >= 0;
    	data = xml ? r.responseXML : r.responseText;

    	// Get the JavaScript object, if JSON is used.
    	if ( type == "json" )
    		data = eval("(" + data + ")");
			
    	return data;
    }

    function param( a ) {
    	var s = [];

    	// If an array was passed in, assume that it is an array
    	// of form elements
    	if ( a.constructor == Array )
    		// Serialize the form elements
    		each( a, function(){
    			s.push( encodeURIComponent(this.name) + "=" + encodeURIComponent( this.value ) );
    		});

    	// Otherwise, assume that it's an object of key/value pairs
    	else
    		// Serialize the key/values
    		for ( var j in a )
    			// If the value is an array then the key names need to be repeated
    			if ( a[j] && a[j].constructor == Array )
    				each( a[j], function(){
    					s.push( encodeURIComponent(j) + "=" + encodeURIComponent( this ) );
    				});
    			else
    				s.push( encodeURIComponent(j) + "=" + encodeURIComponent( a[j] ) );

    	// Return the resulting serialization
    	return s.join("&");
    }

    function each (obj, fn) {
        if (obj.length == undefined)
            for (var i in obj) 
                fn.call(obj[i], i, obj[i]);
        else 
            for ( var i = 0, ol = obj.length, val = obj[0]; 
    			i < ol && fn.call(val,i,val) !== false; val = obj[++i] ){}

    	return obj;
    }

    function ajax( s ) {
    	// if data available
    	if ( s.data ) {
    		// convert data if not already a string
    		if ( s.processData && typeof s.data != "string" )
    			s.data = param(s.data);

    		// append data to url for get requests
    		if ( s.type.toLowerCase() == "get" ) {
    			// "?" + data or "&" + data (in case there are already params)
    			s.url += (s.url.indexOf("?") > -1 ? "&" : "?") + s.data;

    			// IE likes to send both get and post data, prevent this
    			s.data = null;
    		}
    	}

    	var requestDone = false;

    	var xml = new XMLHttpRequest();

    	// Open the socket
    	xml.open(s.type, s.url, s.async);

		if (s.contentType)
			xml.overrideMimeType(s.contentType);

    	// Set the correct header, if data is being sent
    	if ( s.data )
    		xml.setRequestHeader("Content-Type", s.contentType);

    	// Set the If-Modified-Since header, if ifModified mode.
    	if ( s.ifModified )
    		xml.setRequestHeader("If-Modified-Since",
    			lastModified[s.url] || "Thu, 01 Jan 1970 00:00:00 GMT" );

    	// Set header so the called script knows that it's an XMLHttpRequest
    	xml.setRequestHeader("X-Requested-With", "XMLHttpRequest");

    	// Allow custom headers/mimetypes
    	if( s.beforeSend )
    		s.beforeSend(xml);

    	// Wait for a response to come back
    	var onreadystatechange = function(isTimeout){
    		// The transfer is complete and the data is available, or the request timed out
    		if ( !requestDone && xml && (xml.readyState == 4 || isTimeout == "timeout") ) {
    			requestDone = true;

    			// clear poll interval
    			if (ival) {
    				clearInterval(ival);
    				ival = null;
    			}

    			var status = isTimeout == "timeout" && "timeout" ||
    				!httpSuccess( xml ) && "error" ||
    				s.ifModified && httpNotModified( xml, s.url ) && "notmodified" ||
    				"success";

    			if ( status == "success" ) {
    				// Watch for, and catch, XML document parse errors
    				try {
    					// process the data (runs the xml through httpData regardless of callback)
    					var data = httpData( xml, s.dataType );
    				} catch(e) {
    					status = "parsererror";
    				}
    			}

    			// Make sure that the request was successful or notmodified
    			if ( status == "success" ) {
    				// Cache Last-Modified header, if ifModified mode.
    				var modRes;
    				try {
    					modRes = xml.getResponseHeader("Last-Modified");
    				} catch(e) {} // swallow exception thrown by FF if header is not available

    				if ( s.ifModified && modRes )
    					lastModified[s.url] = modRes;

    				// If a local callback was specified, fire it and pass it the data
    				if ( s.success )
    					s.success( data, status );
    			} else
    				if ( s.error ) s.error( xml, status );

    			// Process result
    			if ( s.complete )
    				s.complete(xml, status);

    			// Stop memory leaks
    			if(s.async)
    				xml = null;
    		}
    	};

    	if ( s.async ) {
    		// don't attach the handler to the request, just poll it instead
    		var ival = setInterval(onreadystatechange, 13); 

    		// Timeout checker
    		if ( s.timeout > 0 )
    			setTimeout(function(){
    				// Check to see if the request is still happening
    				if ( xml ) {
    					// Cancel the request
    					xml.abort();

    					if( !requestDone )
    						onreadystatechange( "timeout" );
    				}
    			}, s.timeout);
    	}

    	// Send the data
    	try {
    		xml.send(s.data);
    	} catch(e) {
    		if ( s.error ) s.error( xml, status, e );
    	}

    	// firefox 1.5 doesn't fire statechange for sync requests
    	if ( !s.async )
    		onreadystatechange();

    	// return XMLHttpRequest to allow aborting the request etc.
    	return xml;
    }

	s = extend(true, s, extend(true, {}, ajaxSettings, s));
    
    return ajax(s);
}

function refresh() {
	var er;
	Ajax({
		url: 'http://remysharp.com/',
		dataType: 'html',
		success: function(xml) {
			// convert the HTML to an XML DOM object
			xml = getDOMfromXML(xml);
			var ajax_text = document.getElementById('ajax-text');
			ajax_text.innerHTML = xml.getElementsByTagName('h1')[1].innerText;
		},
		error: function (xhr, er, desc) {
			alert("something went wrong: " + desc);
		}
	});
}

function getDOMfromXML(xml) {
	var d = document.createElement('div');
	xml = xml.substring(xml.indexOf('<body') + xml.substring(xml.indexOf('<body')).indexOf('>')+1);
	xml = xml.substring(0, xml.indexOf('</body>'));
	d.innerHTML = xml;
	
	return d;
}

// This file was generated by Dashcode from Apple Computer, Inc.
// You may edit this file to customize your Dashboard widget.

function load()
{
	setupParts();
}

function remove()
{
	// your widget has just been removed from the layer
	// remove any preferences as needed
	// widget.setPreferenceForKey(null, createInstancePreferenceKey("ajaxify-url"));
}

function hide()
{
	// your widget has just been hidden stop any timers to
	// prevent cpu usage
}

function show()
{
	// your widget has just been shown.  restart any timers
	// and adjust your interface as needed
	refresh();
}

function showBack(event)
{
	// your widget needs to show the back

	var front = document.getElementById("front");
	var back = document.getElementById("back");

	if (window.widget)
		widget.prepareForTransition("ToBack");

	front.style.display="none";
	back.style.display="block";
	
	if (window.widget)
		setTimeout('widget.performTransition();', 0);
}

function showFront(event)
{
	// your widget needs to show the front

	var front = document.getElementById("front");
	var back = document.getElementById("back");

	if (window.widget) {
		widget.prepareForTransition("ToFront");
		refresh();
	}

	front.style.display="block";
	back.style.display="none";
	
	if (window.widget)
		setTimeout('widget.performTransition();', 0);
}

if (window.widget)
{
	widget.onremove = remove;
	widget.onhide = hide;
	widget.onshow = show;
}
